@@ -4,13 +4,14 @@
 #include <sopt/real_type.h>
 #include <sopt/types.h>
 
-template <class TYPE> void function_l1p(benchmark::State &state) {
+template <class TYPE>
+void function_l1p(benchmark::State &state) {
   typedef typename sopt::real_type<TYPE>::type Real;
   auto const N = state.range_x();
   auto const input = sopt::Vector<TYPE>::Random(N).eval();
   auto const Psi = sopt::Matrix<TYPE>::Random(input.size(), input.size() * 10).eval();
-  sopt::Vector<Real> const weights
-      = sopt::Vector<TYPE>::Random(Psi.cols()).normalized().array().abs();
+  sopt::Vector<Real> const weights =
+      sopt::Vector<TYPE>::Random(Psi.cols()).normalized().array().abs();
 
   auto const l1 = sopt::proximal::L1<TYPE>()
                       .tolerance(std::pow(10, -state.range_y()))
@@ -23,8 +24,7 @@ template <class TYPE> void function_l1p(benchmark::State &state) {
 
   Real const gamma = 1e-2 / Psi.array().abs().sum();
   auto output = sopt::Vector<TYPE>::Zero(N).eval();
-  while(state.KeepRunning())
-    l1(output, gamma, input);
+  while (state.KeepRunning()) l1(output, gamma, input);
   state.SetBytesProcessed(int64_t(state.iterations()) * int64_t(N) * sizeof(TYPE));
 }
 
